bat API documentation

# bat

Black-box Adversarial Toolbox (BAT) is a python library for Distrubuted Black-box Attacks against Deep Learning Cloud Services.

## bat.apis

This module implements Python clients of several Cloud APIs, so that we can use `model.predict()` to get predictions from API servers.

- DeepAPI
- Google Cloud Vision
- Imagga

## bat.attacks

This module implements Distributed Black-box Attacks against Deep Learning models.

Local Search:

- SimBA Attack (Guo et al., 2019)
- Square Attack (Andriushchenko et al., 2020)

Gradient Estimation:

- Bandits Attack (Ilyas et al., 2019)

## bat.utils

This module implements utility functions.

View Source

     1r'''
     2Black-box Adversarial Toolbox (BAT) is a python library for **Distrubuted Black-box Attacks** against Deep Learning Cloud Services.
     3
     4## bat.apis
     5
     6This module implements Python clients of several Cloud APIs, so that we can use `model.predict()` to get predictions from API servers.
     7
     8- DeepAPI
     9- Google Cloud Vision
    10- Imagga
    11
    12## bat.attacks
    13
    14This module implements Distributed Black-box Attacks against Deep Learning models.
    15
    16Local Search:
    17
    18- SimBA Attack [(Guo et al., 2019)](https://arxiv.org/abs/1905.07121)
    19- Square Attack [(Andriushchenko et al., 2020)](https://arxiv.org/abs/1912.00049)
    20
    21Gradient Estimation:
    22
    23- Bandits Attack [(Ilyas et al., 2019)](https://arxiv.org/abs/1807.07978)
    24
    25## bat.utils
    26
    27This module implements utility functions.
    28
    29'''
    30
    31# Project Imports
    32from bat import apis
    33from bat import attacks
    34
    35# Semantic Version
    36__version__ = "0.1.0"